@@ -48,6 +48,7 @@ public:
 
   // nsWrapperCache
   using nsWrapperCache::GetWrapperPreserveColor;
+  using nsWrapperCache::PreserveWrapper;
   virtual JSObject* WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto) override;
 protected:
   virtual ~TableRowsCollection();
@@ -56,6 +57,10 @@ protected:
   {
     return nsWrapperCache::GetWrapperPreserveColor();
   }
+  virtual void PreserveWrapperInternal(nsISupports* aScriptObjectHolder) override
+  {
+    nsWrapperCache::PreserveWrapper(aScriptObjectHolder);
+  }
 
   // Those rows that are not in table sections
   HTMLTableElement* mParent;
@@ -359,7 +364,7 @@ NS_IMPL_ADDREF_INHERITED(HTMLTableElement, Element)
 NS_IMPL_RELEASE_INHERITED(HTMLTableElement, Element)
 
 // QueryInterface implementation for HTMLTableElement
-NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION_INHERITED(HTMLTableElement)
+NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION(HTMLTableElement)
 NS_INTERFACE_MAP_END_INHERITING(nsGenericHTMLElement)
 
 
