@@ -191,10 +191,8 @@ CSS_STATE_PSEUDO_CLASS(fullscreen, ":fullscreen",
 CSS_STATE_PSEUDO_CLASS(mozFullScreen, ":-moz-full-screen", 0, "", NS_EVENT_STATE_FULL_SCREEN)
 
 // Matches if a <dialog> element is modal
-CSS_STATE_PSEUDO_CLASS(mozModalDialog, ":-moz-modal-dialog",
-                       CSS_PSEUDO_CLASS_ENABLED_IN_UA_SHEETS,
-                       "",
-                       NS_EVENT_STATE_MODAL_DIALOG)
+CSS_STATE_PSEUDO_CLASS(modal, ":modal", 0, "", NS_EVENT_STATE_MODAL_DIALOG)
+CSS_STATE_PSEUDO_CLASS(mozModalDialog, ":-moz-modal-dialog", 0, "", NS_EVENT_STATE_MODAL_DIALOG)
 
 // Matches if the element is focused and should show a focus ring
 CSS_STATE_PSEUDO_CLASS(mozFocusRing, ":-moz-focusring", 0, "", NS_EVENT_STATE_FOCUSRING)
